@@ -1,4 +1,4 @@
-from tuneflow_py import Song, TrackType
+from tuneflow_py import Song, TrackType, TrackOutputType
 from miditoolkit.midi import MidiFile
 from pathlib import PurePath, Path
 import unittest
@@ -247,9 +247,10 @@ class TestTimeSignature(BaseTest):
         self.assertEqual(time_signature.get_numerator(), 7)
         self.assertEqual(time_signature.get_denominator(), 8)
 
-class TestCloneTrack(BaseTest):
+
+class TestTracks(BaseTest):
     def test_clone_track(self):
-        track1 = self.song.create_track(type=TrackType.MIDI_TRACK, index=0,rank=1)
+        track1 = self.song.create_track(type=TrackType.MIDI_TRACK, index=0, rank=1)
         self.assertEqual(self.song.get_track_count(), 1)
         track1.set_instrument(program=64, is_drum=False)
         track1.set_pan(62)
@@ -260,9 +261,23 @@ class TestCloneTrack(BaseTest):
         self.assertEqual(self.song.get_track_index(track2.get_id()), 0)
         self.assertEqual(track1.get_rank(), 1)
         self.assertEqual(track2.get_rank(), 2)
-        self.assertEqual(track2.get_instrument().program, 64) # type:ignore
-        self.assertEqual(track2.get_instrument().is_drum, False) # type:ignore
+        self.assertEqual(track2.get_instrument().program, 64)  # type:ignore
+        self.assertEqual(track2.get_instrument().is_drum, False)  # type:ignore
         self.assertEqual(track2.get_pan(), 62)
 
+    def test_remove_track(self):
+        track1 = self.song.create_track(type=TrackType.MIDI_TRACK)
+        dep_track = self.song.create_track(type=TrackType.AUX_TRACK)
+        dep_track.get_or_create_output().set_type(TrackOutputType.TRACK_OUTPUT_TRACK)
+        dep_track.get_or_create_output().set_track_id(track1.get_id())
+        self.assertEqual(self.song.get_track_count(), 2)
+        self.assertTrue(dep_track.has_output())
+        self.assertEqual(dep_track.get_output().get_track_id(), track1.get_id())  # type:ignore
+        self.assertEqual(dep_track.get_output().get_type(), TrackOutputType.TRACK_OUTPUT_TRACK)  # type:ignore
+        self.song.remove_track(track1.get_id())
+        self.assertEqual(self.song.get_track_count(), 1)
+        self.assertFalse(dep_track.has_output())
+
+
 if __name__ == '__main__':
     unittest.main()
